require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xdnsserverconditionalforwarder',
  dscmeta_resource_friendly_name: 'xDnsServerConditionalForwarder',
  dscmeta_resource_name: 'MSFT_xDnsServerConditionalForwarder',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xDnsServer',
  dscmeta_module_version: '2.0.0',
  docs: 'The DSC xDnsServerConditionalForwarder resource type.
         Automatically generated from version 2.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_masterservers: {
      type: 'Optional[Array[String]]',
      desc: 'The IP addresses the forwarder should use. Mandatory if Ensure is present.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_directorypartitionname: {
      type: 'Optional[String]',
      desc: 'The name of the directory partition to use when the ReplicationScope is `Custom`. This value is ignored for all other replication scopes.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Ensure whether the zone is absent or present.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_zonetype: {
      type: 'Optional[String]',
      desc: 'The zone type',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of the zone to manage.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_replicationscope: {
      type: "Optional[Enum['None', 'Custom', 'Domain', 'Forest', 'Legacy']]",
      desc: 'Whether the conditional forwarder should be replicated in AD, and the scope of that replication. Default is `None`.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
