require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xdnsserverdiagnostics',
  dscmeta_resource_friendly_name: 'xDnsServerDiagnostics',
  dscmeta_resource_name: 'MSFT_xDnsServerDiagnostics',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xDnsServer',
  dscmeta_module_version: '2.0.0',
  docs: 'The DSC xDnsServerDiagnostics resource type.
         Automatically generated from version 2.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_sendpackets: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs send packets.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_dnsserver: {
      type: 'String',
      desc: "Specifies the DNS server to connect to, or use 'localhost' for the current node.",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_udppackets: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs UDP packets.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableloggingforzoneloadingevent: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs zone load events.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_update: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs updates.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_answers: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to enable the logging of DNS responses.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableloggingforrecursivelookupevent: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs recursive lookup events.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablelogfilerollover: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to enable log file rollover.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_questiontransactions: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs queries.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_logfilepath: {
      type: 'Optional[String]',
      desc: 'Specifies a log file path.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableloggingforremoteserverevent: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs remote server events.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableloggingforserverstartstopevent: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs server start and stop events.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tcppackets: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs TCP packets.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_eventloglevel: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies an event log level. Valid values are Warning, Error, and None.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enableloggingforplugindllevent: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs dynamic link library (DLL) plug-in events.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableloggingfortombstoneevent: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs tombstone events.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_fullpackets: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs full packets.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_usesystemeventlog: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server uses the system event log for logging.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_unmatchedresponse: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs unmatched responses.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_notifications: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs notifications.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableloggingforlocallookupevent: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs local lookup events.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_savelogstopersistentstorage: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server saves logs to persistent storage.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_receivepackets: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs receive packets.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_queries: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server allows query packet exchanges to pass through the content filter, such as the **FilterIPAddressList** parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableloggingforzonedatawriteevent: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs zone data write events.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_filteripaddresslist: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of IP addresses to filter. When you enable logging, traffic to and from these IP addresses is logged. If you do not specify any IP addresses, traffic to and from all IP addresses is logged.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enableloggingtofile: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs logging-to-file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_writethrough: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS server logs write-throughs.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxmbfilesize: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum size of the log file. This parameter is relevant if you set **EnableLogFileRollover** and **EnableLoggingToFile** to `$true`.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
