require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xdnsserverprimaryzone',
  dscmeta_resource_friendly_name: 'xDnsServerPrimaryZone',
  dscmeta_resource_name: 'MSFT_xDnsServerPrimaryZone',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xDnsServer',
  dscmeta_module_version: '2.0.0',
  docs: 'The DSC xDnsServerPrimaryZone resource type.
         Automatically generated from version 2.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_zonefile: {
      type: 'Optional[String]',
      desc: "Name of the DNS Server primary zone file. If not specified, defaults to 'ZoneName.dns'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dynamicupdate: {
      type: "Optional[Enum['None', 'NonSecureAndSecure']]",
      desc: "Primary zone dynamic DNS update option. Defaults to `'None'`.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the DNS Server primary zone',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Whether the DNS zone should be present or absent',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
