require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xdnsserversetting',
  dscmeta_resource_friendly_name: 'xDnsServerSetting',
  dscmeta_resource_name: 'MSFT_xDnsServerSetting',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xDnsServer',
  dscmeta_module_version: '2.0.0',
  docs: 'The DSC xDnsServerSetting resource type.
         Automatically generated from version 2.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_updateoptions: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Restricts the type of records that can be dynamically updated on the server, used in addition to the AllowUpdate settings on Server and Zone objects.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_norecursion: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the DNS Server performs recursive look ups. TRUE indicates recursive look ups are not performed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sendport: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Port on which the DNS Server sends UDP queries to other servers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_defaultrefreshinterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Refresh interval, in hours, set for all Active Directory-integrated zones created on this DNS Server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_localnetpriority: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the DNS Server gives priority to the local net address when returning A records.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_dspollinginterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Interval, in seconds, to poll the DS-integrated zones.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enabledirectorypartitions: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether support for application directory partitions is enabled on the DNS Server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_forwardingtimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Time, in seconds, a DNS Server forwarding a query will wait for resolution from the forwarder before attempting to resolve the query itself.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dnsserver: {
      type: 'String',
      desc: "Specifies the DNS server to connect to, or use 'localhost' for the current node.",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_loglevel: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Indicates which policies are activated in the Event Viewer system log.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_disableautoreversezones: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the DNS Server automatically creates standard reverse look up zones.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_recursionretry: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Elapsed seconds before retrying a recursive look up.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_allowupdate: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies whether the DNS Server accepts dynamic update requests.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_defaultagingstate: {
      type: 'Optional[Boolean]',
      desc: 'Default ScavengingInterval value set for all Active Directory-integrated zones created on this DNS Server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableednsprobes: {
      type: 'Optional[Boolean]',
      desc: 'Specifies the behavior of the DNS Server. When TRUE, the DNS Server always responds with OPT resource records according to RFC 2671, unless the remote server has indicated it does not support EDNS in a prior exchange. If FALSE, the DNS Server responds to queries with OPTs only if OPTs are sent in the original query.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_bootmethod: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Initialization method for the DNS Server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_roundrobin: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the DNS Server round robins multiple A records.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disjointnets: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the default port binding for a socket used to send queries to remote DNS Servers can be overridden.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxcachettl: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum time, in seconds, the record of a recursive name query may remain in the DNS Server cache.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_autoconfigfilezones: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Indicates which standard primary zones that are authoritative for the name of the DNS Server must be updated when the name server changes.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_secureresponses: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the DNS Server exclusively saves records of names in the same subtree as the server that provided them.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_isslave: {
      type: 'Optional[Boolean]',
      desc: 'TRUE if the DNS server does not use recursion when name-resolution through forwarders fails.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_rpcprotocol: {
      type: 'Optional[Integer[-32768, 32767]]',
      desc: 'RPC protocol or protocols over which administrative RPC runs.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt16',
      mof_is_embedded: false,
    },
    dsc_dsavailable: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether there is an available DS on the DNS Server.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_xfrconnecttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Time, in seconds, the DNS Server waits for a successful TCP connection to a remote server when attempting a zone transfer.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_recursiontimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Elapsed seconds before the DNS Server gives up recursive query.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_loosewildcarding: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the DNS Server performs loose wildcarding.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_bindsecondaries: {
      type: 'Optional[Boolean]',
      desc: 'Determines the AXFR message format when sending to non-Microsoft DNS Server secondaries.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_writeauthorityns: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the DNS Server writes NS and SOA records to the authority section on successful response.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_scavenginginterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Interval, in hours, between two consecutive scavenging operations performed by the DNS Server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_listenaddresses: {
      type: 'Optional[Array[String]]',
      desc: 'Enumerates the list of IP addresses on which the DNS Server can receive queries.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_forwarddelegations: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies whether queries to delegated sub-zones are forwarded.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_maxnegativecachettl: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum time, in seconds, a name error result from a recursive query may remain in the DNS Server cache.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_forwarders: {
      type: 'Optional[Array[String]]',
      desc: 'Enumerates the list of IP addresses of Forwarders to which the DNS Server forwards queries.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_autocacheupdate: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the DNS Server attempts to update its cache entries using data from root servers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defaultnorefreshinterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'No-refresh interval, in hours, set for all Active Directory-integrated zones created on this DNS Server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_addressanswerlimit: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of host records returned in response to an address request. Values between `5` and `28` are valid.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enablednssec: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies whether the DNS Server includes DNSSEC-specific RRs, KEY, SIG, and NXT in a response.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ednscachetimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Lifetime, in seconds, of the cached information describing the EDNS version supported by other DNS Servers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dstombstoneinterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Lifetime of tombstoned records in Directory Service integrated zones, expressed in seconds.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_strictfileparsing: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the DNS Server parses zone files strictly.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_namecheckflag: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Indicates the set of eligible characters to be used in DNS names.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
