require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xdnsserverzonescope',
  dscmeta_resource_friendly_name: 'xDnsServerZoneScope',
  dscmeta_resource_name: 'MSFT_xDnsServerZoneScope',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xDnsServer',
  dscmeta_module_version: '2.0.0',
  docs: 'The DSC xDnsServerZoneScope resource type.
         Automatically generated from version 2.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_zonename: {
      type: 'String',
      desc: 'Specify the existing DNS Zone to add a scope to.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_zonefile: {
      type: 'Optional[String]',
      desc: 'Returns the zone scope filename.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Specifies the name of the Zone Scope.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Should this DNS Server Zone Scope be present or absent',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
